@@ -31,8 +31,8 @@
 from abc import ABC, abstractmethod
 from typing import Optional
 
-from dimp import SymmetricKey
-from dimp import ID
+from mkm.crypto import SymmetricKey
+from mkm import ID
 
 
 class CipherKeyDelegate(ABC):
