@@ -35,29 +35,19 @@
     Barrack for cache entities
 """
 
-from abc import abstractmethod
+from abc import ABC, abstractmethod
 from typing import Optional, List
 
-from dimp import NetworkType, ID
-from dimp import User, Group
+from dimp.mkm.address import thanos
+from dimp import EntityType, ID
+from dimp import User, Group, BaseUser, BaseGroup
 from dimp import Meta, Document
 from dimp import Barrack
 
-from .network import ServiceProvider, Station, Robot
-from .group import Polylogue
+from .mkm import ServiceProvider, Station, Bot
 
 
-def thanos(planet: dict, finger: int) -> int:
-    """ Thanos can kill half lives of a world with a snap of the finger """
-    keys = planet.keys()
-    for key in keys:
-        if (++finger & 1) == 1:
-            # kill it
-            planet.pop(key)
-    return finger
-
-
-class Facebook(Barrack):
+class Facebook(Barrack, ABC):
 
     def __init__(self):
         super().__init__()
@@ -77,11 +67,13 @@ class Facebook(Barrack):
         finger = thanos(self.__groups, finger)
         return finger >> 1
 
+    # private
     def cache_user(self, user: User):
         if user.data_source is None:
             user.data_source = self
         self.__users[user.identifier] = user
 
+    # private
     def cache_group(self, group: Group):
         if group.data_source is None:
             group.data_source = self
@@ -135,27 +127,15 @@ class Facebook(Barrack):
         identifier = document.identifier
         if identifier is None:
             return False
-        # NOTICE: if this is a group profile,
-        #             verify it with each member's meta.key
-        #         else (this is a user profile)
+        # NOTICE: if this is a bulletin document for group,
+        #             verify it with the group owner's meta.key
+        #         else (this is a visa document for user)
         #             verify it with the user's meta.key
         if identifier.is_group:
-            # check by each member
-            members = self.members(identifier=identifier)
-            if members is not None:
-                for item in members:
-                    meta = self.meta(identifier=item)
-                    if meta is None:
-                        # FIXME: meta not found for this member
-                        continue
-                    if document.verify(public_key=meta.key):
-                        return True
-            # DISCUSS: what to do about assistants?
-
             # check by owner
             owner = self.owner(identifier=identifier)
             if owner is None:
-                if identifier.type == NetworkType.POLYLOGUE:
+                if identifier.type == EntityType.GROUP:
                     # NOTICE: if this is a polylogue profile
                     #             verify it with the founder's meta.key
                     #             (which equals to the group's meta.key)
@@ -163,9 +143,6 @@ class Facebook(Barrack):
                 else:
                     # FIXME: owner not found for this group
                     return False
-            elif owner in members:
-                # already checked
-                return False
             else:
                 meta = self.meta(identifier=owner)
         else:
@@ -176,52 +153,52 @@ class Facebook(Barrack):
     # group membership
 
     def is_founder(self, member: ID, group: ID) -> bool:
+        # check member's public key with group's meta.key
         g_meta = self.meta(identifier=group)
         assert g_meta is not None, 'failed to get meta for group: %s' % group
         u_meta = self.meta(identifier=member)
         assert u_meta is not None, 'failed to get meta for member: %s' % member
-        return Meta.matches(meta=g_meta, key=u_meta.key)
+        return Meta.match_key(meta=g_meta, key=u_meta.key)
 
     def is_owner(self, member: ID, group: ID) -> bool:
-        if group.type == NetworkType.POLYLOGUE:
+        if group.type == EntityType.GROUP:
+            # this is a polylogue
             return self.is_founder(member=member, group=group)
         raise AssertionError('only Polylogue so far')
 
     def create_user(self, identifier: ID) -> Optional[User]:
         if identifier.is_broadcast:
             # create user 'anyone@anywhere'
-            return User(identifier=identifier)
+            return BaseUser(identifier=identifier)
         # make sure meta exists
         assert self.meta(identifier) is not None, 'failed to get meta for user: %s' % identifier
         # TODO: make sure visa key exists before calling this
-        # check user type
         u_type = identifier.type
-        if u_type in [NetworkType.MAIN, NetworkType.BTC_MAIN]:
-            return User(identifier=identifier)
-        if u_type == NetworkType.ROBOT:
-            return Robot(identifier=identifier)
-        if u_type == NetworkType.STATION:
+        # check user type
+        if u_type == EntityType.STATION:
             # TODO: get station address before create it
-            return Station(identifier=identifier, host='0.0.0.0', port=0)
-        raise TypeError('unsupported user type: %s' % u_type)
+            # return Station(identifier=identifier, host='0.0.0.0', port=0)
+            return Station(identifier=identifier)
+        elif u_type == EntityType.BOT:
+            return Bot(identifier=identifier)
+        # raise TypeError('unsupported user type: %s' % u_type)
+        return BaseUser(identifier=identifier)
 
     def create_group(self, identifier: ID) -> Optional[Group]:
         if identifier.is_broadcast:
             # create group 'everyone@everywhere'
-            return Group(identifier=identifier)
+            return BaseGroup(identifier=identifier)
         # make sure meta exists
         assert self.meta(identifier) is not None, 'failed to get meta for group: %s' % identifier
-        # check group type
         g_type = identifier.type
-        if g_type == NetworkType.POLYLOGUE:
-            return Polylogue(identifier=identifier)
-        if g_type == NetworkType.CHATROOM:
-            raise NotImplementedError('Chatroom not implemented')
-        if g_type == NetworkType.PROVIDER:
+        # check group type
+        if g_type == EntityType.ISP:
             return ServiceProvider(identifier=identifier)
-        raise TypeError('unsupported group type: %s' % g_type)
+        # raise TypeError('unsupported group type: %s' % g_type)
+        return BaseGroup(identifier=identifier)
 
     @property
+    @abstractmethod
     def local_users(self) -> List[User]:
         """
         Get all local users (for decrypting received message)
@@ -230,12 +207,12 @@ class Facebook(Barrack):
         """
         raise NotImplemented
 
-    @property
-    def current_user(self) -> Optional[User]:
-        """ Get current user (for signing and sending message) """
-        users = self.local_users
-        if users is not None and len(users) > 0:
-            return users[0]
+    # @property
+    # def current_user(self) -> Optional[User]:
+    #     """ Get current user (for signing and sending message) """
+    #     users = self.local_users
+    #     if users is not None and len(users) > 0:
+    #         return users[0]
 
     def select_user(self, receiver: ID) -> Optional[User]:
         """ Select local user for receiver """
