@@ -30,7 +30,9 @@
 
 from typing import Optional
 
-from dimp import ID, json_encode, json_decode
+from mkm.crypto import json_encode, json_decode, utf8_encode, utf8_decode
+
+from dimp import ID
 from dimp import Content, Command
 from dimp import InstantMessage, SecureMessage, ReliableMessage
 from dimp import Packer
@@ -79,7 +81,7 @@ class MessagePacker(TwinsHelper, Packer):
         #         if you don't want to share the symmetric key with other members,
         #         you could split it (set group ID into message content and
         #         set contact ID to the "receiver") before encrypting, this usually
-        #         for sending group command to assistant robot, which should not
+        #         for sending group command to assistant bot, which should not
         #         share the symmetric key (group msg key) with other members.
 
         # 1. get symmetric key
@@ -140,14 +142,16 @@ class MessagePacker(TwinsHelper, Packer):
         return msg.sign()
 
     def serialize_message(self, msg: ReliableMessage) -> bytes:
-        return json_encode(o=msg.dictionary)
+        js = json_encode(obj=msg.dictionary)
+        return utf8_encode(string=js)
 
     #
     #   Data -> ReliableMessage -> SecureMessage -> InstantMessage
     #
 
     def deserialize_message(self, data: bytes) -> Optional[ReliableMessage]:
-        dictionary = json_decode(data=data)
+        js = utf8_decode(data=data)
+        dictionary = json_decode(string=js)
         # TODO: translate short keys
         #       'S' -> 'sender'
         #       'R' -> 'receiver'
